Positional arguments in Artist constructors
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Passing all but the very few first arguments positionally in the constructors
of Artists is deprecated. Most arguments will become keyword-only in a future
version.
